/* closeconfirmationdialog.vala
 *
 * Copyright (C) 2009-2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;
using Gee;

public class I4uc.GtkFrontend.CloseConfirmationDialog : Dialog
{
	private ListStore _documents_store;
	private TreeView _documents_view;
	
	private enum Columns
	{
		ACTIVATED,
		TEXT,
		DOCUMENT_URI,
		N_COLUMNS
	}
	
	public CloseConfirmationDialog (Gee.Map<string, string> documents)
	{
		var title_image = new Image.from_stock (STOCK_DIALOG_WARNING, IconSize.DIALOG);
		title_image.set_alignment (0.5f, 0);
		
		var title_str = _("There are %i unsaved documents. Save documents before closing?").printf (documents.size);
		var title_label = new Label ("<b>" + title_str + "</b>");
		title_label.use_markup = true;
		title_label.wrap = true;
		title_label.set_alignment (0, 0.5f);
		
		_documents_store = new ListStore (Columns.N_COLUMNS, typeof (bool), typeof (string), typeof (string));
		_documents_view = new TreeView.with_model (_documents_store);
		_documents_view.has_tooltip = true;
		
		var toggle = new CellRendererToggle ();
		var text = new CellRendererText ();

		var column = new TreeViewColumn ();
		column.pack_start (toggle, false);
		column.add_attribute (toggle, "active", Columns.ACTIVATED);
		_documents_view.append_column (column);
		
		column = new TreeViewColumn ();
		column.pack_start (text, true);
		column.add_attribute (text, "markup", Columns.TEXT);
		_documents_view.append_column (column);
		_documents_view.set_headers_visible (false);

		foreach (var document_uri in documents.keys)
		{
			TreeIter iter;
			_documents_store.append (out iter);
			_documents_store.set (iter, Columns.ACTIVATED, true, 
			                            Columns.TEXT, documents[document_uri],
			                            Columns.DOCUMENT_URI, document_uri);
		}
		
		var vbox = new VBox (false, 0);
		vbox.pack_start (title_label, false, false, 5);
		vbox.pack_start (_documents_view, true, true, 5);
		
		var hbox = new HBox (false, 0);
		hbox.pack_start (title_image, false, false, 5);
		hbox.pack_start (vbox, true, true, 5);
		
		this.vbox.pack_start (hbox, true, true, 5);
		add_button (_("close without saving"), ResponseType.NO);
		add_button (STOCK_CANCEL, ResponseType.CANCEL);
		add_button (STOCK_SAVE, ResponseType.OK);
		set_default_response (ResponseType.OK);
		show_all ();
		
		//connect signals
		toggle.toggled.connect (on_unsaved_document_toggled);
		_documents_view.query_tooltip.connect (on_query_tooltip);
	}
	
	public Gee.List<string> list_selected_documents ()
	{
		var selected_documents = new ArrayList<string> ();
		TreeIter iter;
		if (_documents_store.get_iter_first (out iter))
			do
			{
				bool active;
				string document;
				_documents_store.get (iter, Columns.ACTIVATED, out active, 
				                            Columns.DOCUMENT_URI, out document);
				if (active)
					selected_documents.add (document);
			} while (_documents_store.iter_next (ref iter));
		return selected_documents.read_only_view;
	}
	
	private void on_unsaved_document_toggled (CellRendererToggle toggle, string path)
	{
		TreeIter iter;
		_documents_store.get_iter_from_string (out iter, path);
		_documents_store.set (iter, Columns.ACTIVATED, !toggle.active);
	}
	
	private bool on_query_tooltip (int x, int y, bool keyboard_tooltip, Tooltip tooltip)
	{
		TreeIter iter;
		string document_uri;
		if (!_documents_view.get_tooltip_context (out x, out y, keyboard_tooltip, null, null, out iter))
			return false;
		_documents_store.get (iter, Columns.DOCUMENT_URI, out document_uri);
		tooltip.set_markup ("<b>%s</b> %s".printf (_("Location:"), document_uri));
		return true;
	}
}
