/* documentpreferencespageview.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;

public class I4uc.GtkFrontend.DocumentPreferencesPageView : Page, I4uc.Core.DocumentPreferencesPageView
{
	private FontButton _source_font = new FontButton ();
	private SpinButton _tab_width = new SpinButton.with_range (1, 32, 1);
	private ToggleButton _auto_indent_button = new ToggleButton.with_label (_("Auto indent"));
	private ToggleButton _highlight_current_line_button = new ToggleButton.with_label (_("Highlight current line"));
	private ToggleButton _insert_spaces_instead_of_tabs_button = new ToggleButton.with_label (_("Insert spaces instead of tabs"));
	private ToggleButton _show_line_numbers_button = new ToggleButton.with_label (_("Show line numbers"));
	private ToggleButton _highlight_matching_brackets_button = new ToggleButton.with_label (_("Highlight matching brackets"));
	private ToggleButton _wrap_mode_button = new ToggleButton.with_label (_("Enable text wrapping"));
	
	public string font_name { set; get; }
	
	public int tab_width
	{
		set { _tab_width.value = value; }
		get { return (int)_tab_width.value; }
	}
	
	public bool auto_indent { set; get; }
	public bool highlight_current_line { set; get; }
	public bool insert_spaces_instead_of_tabs { set; get; }
	public bool show_line_numbers { set; get; }
	public bool highlight_matching_brackets { set; get; }
	public bool wrap_mode { set; get; }
	
	public DocumentPreferencesPageView ()
	{
		base.with_side_label ();
		
		var vbox = new VBox (false, 0);
		vbox.border_width = 2;
		
		Utils.add_vbox_label (vbox, _("Font type:"), _source_font);
		vbox.pack_start (new VSeparator (), false, false, 4);
		Utils.add_vbox_label (vbox, _("Tab width:"), _tab_width);
		vbox.pack_start (new VSeparator (), false, false, 4);
		vbox.pack_start (_auto_indent_button, false, false, 2);
		vbox.pack_start (_highlight_current_line_button, false, false, 2);
		vbox.pack_start (_insert_spaces_instead_of_tabs_button, false, false, 2);
		vbox.pack_start (_show_line_numbers_button, false, false, 2);
		vbox.pack_start (_highlight_matching_brackets_button, false, false, 2);
		vbox.pack_start (_wrap_mode_button, false, false, 2);
		
		var scrolled_window = new ScrolledWindow (null, null);
		scrolled_window.add_with_viewport (vbox);
		scrolled_window.set_policy (PolicyType.NEVER, PolicyType.AUTOMATIC);
		
		pack_start (scrolled_window, true, true, 2);
		show_all ();
		
		//Bind properties
		bind_property ("font-name", _source_font, "font-name", BindingFlags.BIDIRECTIONAL);
		bind_property ("auto-indent", _auto_indent_button, "active", BindingFlags.BIDIRECTIONAL);
		bind_property ("highlight-current-line", _highlight_current_line_button, "active", BindingFlags.BIDIRECTIONAL);
		bind_property ("insert-spaces-instead-of-tabs", _insert_spaces_instead_of_tabs_button, "active", BindingFlags.BIDIRECTIONAL);
		bind_property ("show-line-numbers", _show_line_numbers_button, "active", BindingFlags.BIDIRECTIONAL);
		bind_property ("highlight-matching-brackets", _highlight_matching_brackets_button, "active", BindingFlags.BIDIRECTIONAL);
		bind_property ("wrap-mode", _wrap_mode_button, "active", BindingFlags.BIDIRECTIONAL);
		
		//Connect signals
		_tab_width.value_changed.connect (() => notify_property ("tab-width"));
	}
}
