/* itemschecklist.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;
using Gee;

public class I4uc.GtkFrontend.ItemsCheckList : Gtk.VBox
{
	private ListStore _items_store;
	private TreeView _items_view;

	private ArrayList<string> _items = new ArrayList<string> ();

	private enum ItemsColumns
	{
		ACTIVE,
		ITEM,
		N_COLUMNS
	}

	public Gee.List<string> activated_items
	{
		owned get
		{
			var activated_items = new ArrayList<string> ();
			TreeIter iter;
			if (_items_store.get_iter_first (out iter))
			{
				do
				{
					bool active;
					string item;
					_items_store.get (iter, ItemsColumns.ACTIVE, out active, ItemsColumns.ITEM, out item);
					if (active)
						activated_items.add (item);
				} while (_items_store.iter_next (ref iter));
			}
			return activated_items.read_only_view;
		}
	}

	public signal void check_changed (string item, bool active);

	public ItemsCheckList ()
	{
		_items_store = new ListStore (ItemsColumns.N_COLUMNS, typeof (bool), typeof (string));
		_items_view = new TreeView.with_model (_items_store);
		
		var column = new TreeViewColumn ();
		var toggle = new CellRendererToggle ();
		column.pack_start (toggle, false);
		column.add_attribute (toggle, "active", ItemsColumns.ACTIVE);
		_items_view.append_column (column);
		column = new TreeViewColumn ();
		var renderer = new CellRendererText ();
 		column.pack_start (renderer, false);
		column.add_attribute (renderer, "text", ItemsColumns.ITEM);
		_items_view.append_column (column);
		_items_view.set_headers_visible (false);
		
		pack_start (_items_view, true, true, 0);

		//Connect signals
		toggle.toggled.connect (on_item_toggled);
	}
	
	public void add_item (string item, bool active)
	{
		if (item in _items)
			return;
		TreeIter iter;
		_items_store.append (out iter);
		_items_store.set (iter, ItemsColumns.ACTIVE, active, ItemsColumns.ITEM, item);
		_items.add (item);
	}

	public void check_item (string item, bool active)
	{
		if (!(item in _items))
			return;
		TreeIter iter;
		_items_store.get_iter_from_string (out iter, _items.index_of (item).to_string ());
		_items_store.set (iter, ItemsColumns.ACTIVE, active);
	}

	public void uncheck_all_items ()
	{
		foreach (var item in _items)
		{
			TreeIter iter;
			_items_store.get_iter_from_string (out iter, _items.index_of (item).to_string ());
			_items_store.set (iter, ItemsColumns.ACTIVE, false);
		}
	}
	
	public void clear_list ()
	{
		_items.clear ();
		_items_store.clear ();
	}
	
	private void on_item_toggled (CellRendererToggle toggle, string path)
	{
		TreeIter iter;
		_items_store.get_iter_from_string (out iter, path);
		_items_store.set (iter, ItemsColumns.ACTIVE, !toggle.active);
		this.check_changed (_items[path.to_int ()], !toggle.active);
	}
}
