/* newprojectdialog.vala
 *
 * Copyright (C) 2009-2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;

public class I4uc.GtkFrontend.NewProjectDialog : Gtk.Dialog
{
	private FileChooserButton _folder_chooser;
	private Entry _name_entry = new Entry ();

	public string project_name { get { return _name_entry.text; } }
	public string project_uri { owned get { return _folder_chooser.get_current_folder_file ().get_child_for_display_name (_name_entry.text + ".i4uc").get_uri (); } }

	public NewProjectDialog ()
	{
		//Project folder
		_folder_chooser = new FileChooserButton (_("New project"), FileChooserAction.SELECT_FOLDER);
		_folder_chooser.set_current_folder (Environment.get_home_dir ());

		//Project folder
		Utils.add_vbox_label (this.vbox, _("Folder:"), _folder_chooser);
		this.vbox.pack_start (new VSeparator (), false, false, 5);

		//Project name
		Utils.add_vbox_label (this.vbox, _("Name:"), _name_entry);
		this.vbox.pack_start (new VSeparator (), false, false, 5);

		//Buttons
		add_button (STOCK_CANCEL, ResponseType.CANCEL);
		add_button (STOCK_OK, ResponseType.OK);
		set_response_sensitive (ResponseType.OK, false);
		set_default_response (ResponseType.OK);
		this.vbox.show_all ();

		//Connect signals
		_name_entry.changed.connect (on_name_changed);
	}
	
	private void on_name_changed ()
	{
		var is_valid_name = _name_entry.text != "" || !_name_entry.text.has_prefix (".");
		set_response_sensitive (ResponseType.OK, is_valid_name);
	}
}
