/* optionsview.vala
 *
 * Copyright (C) 2011  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;

public class I4uc.GtkFrontend.OptionsView : Gtk.VBox, I4uc.Core.OptionsView
{
	private VBox _options_vbox = new VBox (false, 3);
	private Expander _extra_options_expander = new Expander ("<b>" + _("More options") + "</b>");
	private VBox _extra_options_vbox = new VBox (false, 3);
	
	public bool extra_options_visible { set; get; }
	
	public OptionsView ()
	{
		this.border_width = 3;
		
		_extra_options_expander.use_markup = true;
		_extra_options_expander.add (_extra_options_vbox);
		
		pack_start (_options_vbox, false, false, 3);
		pack_end (_extra_options_expander, false, false, 3);
		
		bind_property ("extra-options-visible", _extra_options_expander, "visible", BindingFlags.BIDIRECTIONAL);
	}
	
	public I4uc.Core.OptionView add_option (string name, string label, string value_type, bool optional, bool most_used)
	{
		OptionView option = null;
		switch (value_type)
		{
			case "None":
				option = new NoneOptionView (name, label);
				break;
			case "Entry":
				option = new EntryOptionView (name, label, optional);
				break;
			case "List":
			case "SerialPort":
			case "BaudRate":
			case "UDevList":
				option = new ListOptionView (name, label, optional);
				break;
			case "FilePath":
				option = new FilePathOptionView (name, label, optional);
				break;
			case "FolderPath":
				option = new FolderPathOptionView (name, label, optional);
				break;
			case "Range":
				option = new RangeOptionView (name, label, optional);
				break;
		}
		if (most_used)
		{
			_options_vbox.pack_start (option, false, false, 2);
			_options_vbox.show_all ();
		}
		else
		{
			_extra_options_vbox.pack_start (option, false, false, 2);
			_extra_options_vbox.show_all ();
		}
		return option;
	}
	
	public void clear_options ()
	{
		// Remove and create options vbox
		remove (_options_vbox);
		_options_vbox = new VBox (false, 3);
		pack_start (_options_vbox, false, false, 3);
		
		// Remove and create extra options vbox
		_extra_options_expander.remove (_extra_options_vbox);
		_extra_options_vbox = new VBox (false, 3);
		_extra_options_expander.add (_extra_options_vbox);
	}
}
