/* page.vala
 *
 * Copyright (C) 2009-2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;

public class I4uc.GtkFrontend.Page : Gtk.VBox, I4uc.Core.Page
{
	private Image _tab_image = new Image.from_stock (STOCK_FILE, IconSize.MENU);
	private Label _tab_title_label = new Label (null);
	private Label _tab_mark = new Label (null);
	
	public string title { set; get; }
	public Box tab_label { private set; get; }
	
	public I4uc.Core.TabImage tab_image
	{
		set { _tab_image.set_from_stock (TabImages.get_stock_item (value), IconSize.MENU); }
		get { return TabImages.get_tab_image (_tab_image.stock); }
	}
	
	public string tab_title { set; get; }
	
	public bool tab_mark
	{
		set { _tab_mark.label = (value ? "*" : ""); }
		get { return _tab_mark.label == "*"; }
	}
	
	public string tab_tooltip { set; get; }
	
	public Page ()
	{
		_tab_label = new HBox (false, 5);
		_tab_label.pack_start (_tab_image, false, false, 0);
		_tab_label.pack_start (_tab_mark, false, false, 0);
		_tab_label.pack_start (_tab_title_label, false, false, 0);
		_tab_label.show_all ();
		
		//Bind properties
		bind_property ("tab-title", _tab_title_label, "label", BindingFlags.BIDIRECTIONAL);
		bind_property ("tab-tooltip", _tab_label, "tooltip-markup", BindingFlags.BIDIRECTIONAL);
	}
	
	public Page.with_close_button ()
	{
		this ();
		
		var close_button = Utils.create_close_button ();
		close_button.clicked.connect (() => this.close_clicked ());
		close_button.tooltip_text = _("Close page");
		
		_tab_label.pack_start (close_button, false, false, 0);
		_tab_label.show_all ();
	}
	
	public Page.with_side_label ()
	{
		_tab_label = new VBox (false, 0);
		_tab_title_label.angle = 90.0;
		_tab_label.pack_start (_tab_title_label, false, false, 2);
		_tab_label.show_all ();
		
		//Bind properties
		bind_property ("tab-title", _tab_title_label, "label", BindingFlags.BIDIRECTIONAL);
	}
}
