/* pagespanel.vala
 *
 * Copyright (C) 2009-2011  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;
using Gee;

public class I4uc.GtkFrontend.PagesPanel : Gtk.VBox, I4uc.Core.PagesPanel
{
	private Notebook _notebook = new Notebook ();
	private ArrayList<I4uc.Core.Page> _pages = new ArrayList<I4uc.Core.Page> ();
	private Page _current_page;
	
	public I4uc.Core.Page current_page { get { return _current_page; } }
	
	public I4uc.Core.PagePosition page_position
	{
		set { _notebook.tab_pos = PagePositions.get_position_type (value); }
		get { return PagePositions.get_page_position (_notebook.tab_pos); }
	}
	
	public PagesPanel ()
	{
		_notebook.scrollable = true;
		
		_notebook.switch_page.connect ((panel, page, page_num) => {
			_current_page = (_notebook.get_nth_page ((int)page_num) as Page);
			this.page_changed (_current_page);
		});
		_notebook.page_added.connect ((panel, page, page_num) => {
			_pages.add (page as Page);
			this.page_added (page as Page);
		});
		_notebook.page_removed.connect ((panel, page, page_num) => {
			_pages.remove (page as Page);
			this.page_removed (page as Page);
			if (_notebook.get_n_pages () == 0)
			{
				_current_page = null;
				this.page_changed (_current_page);
			}
		});
		
		pack_start (_notebook, true, true, 0);
	}

	public int get_page_num (I4uc.Core.Page page)
	{
		return _notebook.page_num (page as Page);
	}
	
	public int get_num_of_pages ()
	{
		return _notebook.get_n_pages ();
	}
	
	public void add_page (I4uc.Core.Page page)
	{
		_notebook.append_page (page as Page, (page as Page).tab_label);
	}
	
	public void insert_page (I4uc.Core.Page page, int position)
	{
		_notebook.insert_page (page as Page, (page as Page).tab_label, position);
	}
	
	public void remove_page (I4uc.Core.Page page)
	{
		_notebook.remove_page (get_page_num (page));
	}
	
	public void show_page (I4uc.Core.Page page)
	{
		_notebook.set_current_page (get_page_num (page));
	}
	
	public Gee.List<I4uc.Core.Page> list_pages ()
	{
		return _pages.read_only_view;
	}
	
	public void previous_page ()
	{
		_notebook.prev_page ();
	}
	
	public void next_page ()
	{
		_notebook.next_page ();
	}
}
