/* programmersview.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;

public class I4uc.GtkFrontend.ProgrammersView : GLib.Object, I4uc.Core.ProgrammersView
{
	private UIManager _ui_manager;
	private Gtk.ActionGroup _action_group;
	private PagesPanel _pages_panel;
	private PagesPanel _side_panel;
	private PagesPanel _bottom_panel;
	private ProgrammersPage _page = new ProgrammersPage ();
	private LogPage _log_page = new LogPage ();
	
	public I4uc.Core.PagesPanel pages_panel { get { return _pages_panel; } }
	public I4uc.Core.ProgrammersPage page { get { return _page; } }
	public I4uc.Core.LogPage log_page { get { return _log_page; } }
	
	public bool write_flash_sensitive { set; get; }
	public bool read_flash_sensitive { set; get; }
	public bool verify_flash_sensitive { set; get; }
	public bool erase_flash_sensitive { set; get; }
	public bool write_fuses_sensitive { set; get; }
	public bool read_fuses_sensitive { set; get; }
	public bool get_version_sensitive { set; get; }
	public bool stop_sensitive { set; get; }
	
	public ProgrammersView (UIManager ui_manager, PagesPanel pages_panel, PagesPanel side_panel, PagesPanel bottom_panel)
	{
		_ui_manager = ui_manager;
		_pages_panel = pages_panel;
		_side_panel = side_panel;
		_bottom_panel = bottom_panel;
		
		_action_group = new Gtk.ActionGroup ("I4ucProgrammersActions");
		_action_group.set_translation_domain (Config.GETTEXT_PACKAGE);
		_action_group.add_actions (_action_entries, this);
		
		_ui_manager.insert_action_group (_action_group, -1);
		
		try
		{
			_ui_manager.add_ui_from_string (_UI, -1);
		}
		catch (GLib.Error e)
		{
			warning (e.message);
		}
		
		var toolbar = (Toolbar)_ui_manager.get_widget ("/MainToolbar");
		toolbar.set_style (ToolbarStyle.ICONS);
		
		_side_panel.insert_page (_page, 1);
		_bottom_panel.add_page (_log_page);
		
		//Bind properties
		bind_property ("write-flash-sensitive", _action_group.get_action ("WriteFlashProgrammerAction"), "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("read-flash-sensitive", _action_group.get_action ("ReadFlashProgrammerAction"), "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("verify-flash-sensitive", _action_group.get_action ("VerifyFlashProgrammerAction"), "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("erase-flash-sensitive", _action_group.get_action ("EraseFlashProgrammerAction"), "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("write-fuses-sensitive", _action_group.get_action ("WriteFusesProgrammerAction"), "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("read-fuses-sensitive", _action_group.get_action ("ReadFusesProgrammerAction"), "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("get-version-sensitive", _action_group.get_action ("GetVersionProgrammerAction"), "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("stop-sensitive", _action_group.get_action ("StopProgrammerAction"), "sensitive", BindingFlags.BIDIRECTIONAL);
	}
	
	public void show_log_page ()
	{
		_bottom_panel.show_page (_log_page);
	}
	
	public void on_write_flash ()
	{
		this.write_flash_clicked ();
	}
	
	public void on_read_flash ()
	{
		this.read_flash_clicked ();
	}
	
	public void on_verify_flash ()
	{
		this.verify_flash_clicked ();
	}
	
	public void on_erase_flash ()
	{
		this.erase_flash_clicked ();
	}
	
	public void on_write_fuses ()
	{
		this.write_fuses_clicked ();
	}
	
	public void on_read_fuses ()
	{
		this.read_fuses_clicked ();
	}
	
	public void on_get_version ()
	{
		this.get_version_clicked ();
	}
	
	public void on_stop ()
	{
		this.stop_clicked ();
	}
	
	private const ActionEntry[] _action_entries =
	{
		{ "ProgrammersMenuAction", null, N_("_Programmers") },
		{ "WriteFlashProgrammerAction", "i4uc-write-flash", N_("Write flash"), "<Control>F8", N_("Write to flash memory"), on_write_flash },
		{ "ReadFlashProgrammerAction", "i4uc-read-flash", N_("Read flash"), null, N_("Read flash memory"), on_read_flash },
		{ "VerifyFlashProgrammerAction", "i4uc-verify-flash", N_("Verify flash"), null, N_("Verify flash memory"), on_verify_flash },
		{ "EraseFlashProgrammerAction", "i4uc-erase-flash", N_("Erase flash"), null, N_("Erase flash memory"), on_erase_flash },
		{ "WriteFusesProgrammerAction", null, N_("Write fuses"), null, N_("Write fuses"), on_write_fuses },
		{ "ReadFusesProgrammerAction", null, N_("Read fuses"), null, N_("Read fuses"), on_read_fuses },
		{ "GetVersionProgrammerAction", null, N_("Get version"), null, N_("Get version of programmer"), on_get_version },
		{ "StopProgrammerAction", STOCK_STOP, N_("Stop"), "", N_("Stop programmer action"), on_stop }
	};
	
	private const string _UI = """
<ui>
	<menubar name="MainMenu">
		<placeholder name="MenuBarOps">
			<menu name="ProgrammersMenu" action="ProgrammersMenuAction">
				<menuitem action="WriteFlashProgrammerAction"/>
				<menuitem action="ReadFlashProgrammerAction"/>
				<menuitem action="VerifyFlashProgrammerAction"/>
				<menuitem action="EraseFlashProgrammerAction"/>
				<menuitem action="WriteFusesProgrammerAction"/>
				<menuitem action="ReadFusesProgrammerAction"/>
				<menuitem action="GetVersionProgrammerAction"/>
				<menuitem action="StopProgrammerAction"/>
			</menu>
		</placeholder>
	</menubar>
	<toolbar name="MainToolbar">
		<placeholder name="ToolbarEndOps">
			<separator/>
				<toolitem action="WriteFlashProgrammerAction"/>
				<toolitem action="ReadFlashProgrammerAction"/>
				<toolitem action="VerifyFlashProgrammerAction"/>
				<toolitem action="EraseFlashProgrammerAction"/>
				<toolitem action="StopProgrammerAction"/>
			<separator/>
		</placeholder>
	</toolbar>
</ui>""";
}
