/* projectspageview.vala
 *
 * Copyright (C) 2010-2011  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gtk;
using Gee;

public class I4uc.GtkFrontend.ProjectsPageView : Page, I4uc.Core.ProjectsPageView
{
	private ItemsCombo _projects_combo = new ItemsCombo (_("Project:"));
	private ItemsCombo _profiles_combo = new ItemsCombo.with_button (_("Profile:"), STOCK_EDIT);
	private FilesList _files_list = new FilesList ();
	private VBox _profiles_vbox = new VBox (false, 0);
	private ItemsCheckList _profiles_check_list = new ItemsCheckList ();
	private BuildersList _builders_list = new BuildersList ();

	public string current_project { set; get; }
	public string current_project_tooltip { set; get; }
	public string current_profile { set; get; }
	
	public string current_file { get { return _files_list.current_file; } }

	public bool profiles_check_list_sensitive { set; get; }
	public bool profiles_check_list_visible { set; get; }

	public I4uc.Core.BuildersList builders_list { get { return _builders_list; } }
	
	public bool builders_list_sensitive { set; get; }
	public bool builders_list_visible { set; get; }
	public bool profile_edit_sensitive { set; get; }

	public ProjectsPageView ()
	{
		base.with_side_label ();
		
		// Prepare file list
		var files_scrolled_window = new ScrolledWindow (null, null);
		files_scrolled_window.add_with_viewport (_files_list);
		files_scrolled_window.set_policy (PolicyType.NEVER, PolicyType.AUTOMATIC);
		
		// Prepare profiles list
		var scrolled_window = new ScrolledWindow (null, null);
		scrolled_window.add_with_viewport (_profiles_check_list);
		scrolled_window.set_policy (PolicyType.NEVER, PolicyType.AUTOMATIC);
		Utils.add_vbox_label (_profiles_vbox, _("Profiles file:"), scrolled_window);

		// Pack widgets
		var up_vbox = new VBox (false, 0);
		up_vbox.pack_start (_projects_combo, false, false, 2);
		up_vbox.pack_start (_profiles_combo, false, false, 2);
		up_vbox.pack_start (files_scrolled_window, true, true, 2);
		
		var down_vbox = new VBox (false, 0);
		down_vbox.pack_start (_profiles_vbox, true, true, 2);
		down_vbox.pack_start (_builders_list, true, true, 2);
		
		var vpaned = new VPaned ();
		vpaned.pack1 (up_vbox, true, true);
		vpaned.pack2 (down_vbox, false, true);
		pack_start (vpaned, true, true, 0);
		
		show_all ();
		
		//Bind properties
		bind_property ("current-project", _projects_combo, "current-item", BindingFlags.BIDIRECTIONAL);
		bind_property ("current-project-tooltip", _projects_combo, "current-item-tooltip", BindingFlags.BIDIRECTIONAL);
		bind_property ("current-profile", _profiles_combo, "current-item", BindingFlags.BIDIRECTIONAL);
		bind_property ("profiles-check-list-sensitive", _profiles_check_list, "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("profiles-check-list-visible", _profiles_vbox, "visible", BindingFlags.BIDIRECTIONAL);
		bind_property ("builders-list-sensitive", _builders_list, "sensitive", BindingFlags.BIDIRECTIONAL);
		bind_property ("builders-list-visible", _builders_list, "visible", BindingFlags.BIDIRECTIONAL);
		bind_property ("profile-edit-sensitive", _profiles_combo, "button-sensitive", BindingFlags.BIDIRECTIONAL);

		//connect signals
		_profiles_combo.button_clicked.connect (() => this.profile_edit_clicked ());
		_files_list.file_changed.connect (() => this.file_changed ());
		_files_list.file_activated.connect (() => this.file_activated ());
		_profiles_check_list.check_changed.connect ((profile, active) => this.profile_check_changed (profile, active));
	}

	public void add_project (string project_uri, string project_name)
	{
		_projects_combo.add_item (project_uri, project_name);
	}

	public void add_profile (string profile_id, string? profile_label=null, bool on_check_list=true)
	{
		if (on_check_list)
			_profiles_check_list.add_item (profile_id, false);
		_profiles_combo.add_item (profile_id, profile_label);
	}
	
	public void change_profile (string profile_id, string new_profile_id, string? new_profile_label=null)
	{
		_profiles_combo.change_item (profile_id, new_profile_id, new_profile_label);
	}

	public void add_file (string file)
	{
		_files_list.add_file (file);
	}

	public void check_profile (string profile, bool active)
	{
		_profiles_check_list.check_item (profile, active);
	}

	public void uncheck_all_profiles ()
	{
		_profiles_check_list.uncheck_all_items ();
	}

	public void remove_project (string project_uri)
	{
		_projects_combo.remove_item (project_uri);
	}

	public void remove_profile (string profile)
	{
		_profiles_combo.remove_item (profile);
	}

	public void remove_file (string file)
	{
		_files_list.remove_file (file);
	}

	public void clear_profiles_list ()
	{
		_profiles_check_list.clear_list ();
		_profiles_combo.clear_list ();
	}

	public void clear_files_list ()
	{
		_files_list.clear_list ();
	}

	public I4uc.Core.ProfileDialogView create_profile_dialog_view ()
	{
		return new ProfileDialogView ();
	}
}
