/* addprofiledialoglogic.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gee;

public class I4uc.Core.AddProfileDialogLogic : GLib.Object
{
	private AddProfileDialogView _view;
	private Project _project;
	private string _last_project;

	public AddProfileDialogLogic (AddProfileDialogView view, Project project)
	{
		_view = view;
		_project = project;

		//Configure view
		_view.warning_message_visible = false;
		_view.import_project_sensitive = false;
		_view.import_profile_sensitive = false;
		_view.accept_sensitive = false;
		_view.folder_uri = _project.folder_uri;

		//Connect view signals
		_view.is_new_changed.connect (on_is_new_changed);
		_view.new_profile_changed.connect (on_new_profile_changed);
		_view.import_project_changed.connect (on_import_project_changed);
		_view.import_profile_changed.connect (on_import_profile_changed);
	}

	public bool run ()
	{
		if (_view.run () == DialogResponse.CANCEL)
			return false;
		return true;
	}

	private void on_is_new_changed ()
	{
		var is_new = _view.is_new;
		_view.new_profile_sensitive = is_new;
		_view.import_project_sensitive = !is_new;
		_view.import_profile_sensitive = !is_new;
		if (is_new)
			on_new_profile_changed ();
		else
		{
			on_import_project_changed ();
			on_import_profile_changed ();
		}
	}

	private void on_new_profile_changed ()
	{
		var profile_name = _view.profile_name;
		_view.accept_sensitive = !(profile_name == "" ||
		                           profile_name.has_prefix (".") ||
		                           profile_name in _project.profiles.keys);
		if (profile_name in _project.profiles.keys)
			_view.warning_message = _("The profile already exists in the project");
		_view.warning_message_visible = profile_name in _project.profiles.keys;
	}

	private void on_import_project_changed ()
	{
		_view.import_profile_sensitive = false;
		_view.accept_sensitive = false;
		if (_view.project_uri == "" || _view.project_uri == null)
			return;
		if (_view.project_uri == _project.uri)
		{
			_view.warning_message = _("Can't choose the same project");
			_view.warning_message_visible = true;
			return;
		}

		if (_view.project_uri != _last_project)
		{
			var import_project = new Project ();
			try
			{
				import_project.open (_view.project_uri);
			}
			catch (GLib.Error e)
			{
				_view.warning_message = _("Can't open the project: ") + e.message;
				_view.warning_message_visible = true;
				return;
			}
	
			_view.clear_profiles_list ();
			var public_profiles = new ArrayList<string> ();
			foreach (var profile in import_project.profiles.values)
				if (profile.is_public)
					public_profiles.add (profile.name);
			_view.add_profiles (public_profiles);
			_last_project = _view.project_uri;
		}

		_view.warning_message_visible = false;
		_view.import_profile_sensitive = true;
		_view.accept_sensitive = true;
	}

	private void on_import_profile_changed ()
	{
		_view.accept_sensitive = false;
		if (_view.profile_name == "" || _view.profile_name == null)
			return;
		if (_view.profile_name in _project.profiles.keys)
		{
			_view.warning_message = _("There's already a profile with that name");
			_view.warning_message_visible = true;
			return;
		}

		_view.warning_message_visible = false;
		_view.accept_sensitive = true;
	}
}
