/* options.vala
 *
 * Copyright (C) 2011  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gee;

public class I4uc.Core.Option : GLib.Object
{
	private HashMap<string, string> _label = new HashMap<string, string> ();
	private HashMap<string, string> _description = new HashMap<string, string> ();
	private ArrayList _depends = new ArrayList<string> ();
	private string _label_lang;
	private string _description_lang;
	
	public string name { set; get; default = ""; }
	public string format { set; get; default = ""; }
	public string value_type { set; get; default = ""; }
	public bool optional { set; get; default = true; }
	public bool most_used { set; get; default = true; }
	public Gee.Map<string, string> label { get { return _label; } }
	public Gee.Map<string, string> description { get { return _description; } }
	public Gee.List<string> depends { get { return _depends; } }
	
	public string locale_label
	{
		owned get
		{
			if (_label_lang == null)
			{
				_label_lang = "en";
				foreach (var lang in Intl.get_language_names ())
					if (_label.has_key (lang))
						_label_lang = lang;
			}
			return _label[_label_lang];
		}
	}
	
	public string locale_description
	{
		owned get
		{
			if (_description_lang == null)
			{
				_description_lang = "en";
				foreach (var lang in Intl.get_language_names ())
					if (_description.has_key (lang))
						_description_lang = lang;
			}
			return _description[_description_lang];
		}
	}
}

public class I4uc.Core.ListOption : Option
{
	private ArrayList _items = new ArrayList<string> ();
	
	public Gee.List<string> items { get { return _items; } }
	public string default { set; get; default = ""; }
}

public class I4uc.Core.RangeOption : Option
{
	public int min { set; get; }
	public int max { set; get; }
	public int step { set; get; }
	public int default { set; get; }
}

public class I4uc.Core.UDevOption : ListOption
{
	public string subsystem { set; get; }
	public string property_id { set; get; }
	public string property_value { set; get; }
}

public class I4uc.Core.OptionSettings : GLib.Object
{
	public string name { set; get; }
	public string value { set; get; }
	public bool active { set; get; }
	
	public string to_xml (string prefix)
	{
		var xml_str = "<option_value name=\"%s\" value=\"%s\" active=\"%s\"/>\n";
		return prefix + xml_str.printf (_name, _value, _active.to_string ());
	}
	
	public OptionSettings duplicate ()
	{
		var new_option = new OptionSettings ();
		new_option.name = this.name;
		new_option.value = this.value;
		new_option.active = this.active;
		return new_option;
	}
}
