/* profiledialoglogic.vala
 *
 * Copyright (C) 2010  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */

public class I4uc.Core.ProfileDialogLogic : GLib.Object
{
	private ProfileDialogView _view;
	private Project _project;
	private Profile _profile;
	private bool _duplicate_profile;
	
	public ProfileDialogLogic (ProfileDialogView view, Project project, Profile profile, bool duplicate_profile=false)
	{
		_view = view;
		_project = project;
		_profile = profile;
		_duplicate_profile = duplicate_profile;
		
		//Configure view
		_view.warning_message_visible = false;
		_view.title = _duplicate_profile ? _("Duplicate profile") : _("Edit profile");
		if (!_duplicate_profile)
			_view.profile_name = _profile.name;
		_view.is_public = _profile.is_public;
		foreach (var file in _project.files)
			_view.add_file (file, file in _profile.files);
		on_profile_name_changed ();
		
		//Connect view signals
		_view.notify["profile-name"].connect (on_profile_name_changed);
	}
	
	public bool run ()
	{
		if (_view.run () == DialogResponse.CANCEL)
			return false;
		
		if (_duplicate_profile)
			return true;
			
		if (_profile.name != _view.profile_name ||
		    _profile.is_public != _view.is_public ||
		    !_view.activated_files.contains_all (_profile.files) ||
		    !_profile.files.contains_all (_view.activated_files))
			return true;
		
		return false;
	}
	
	private void on_profile_name_changed ()
	{
		_view.accept_sensitive = false;
		if (_view.profile_name == "" || _view.profile_name == null)
			return;
		if ((_duplicate_profile && _view.profile_name == _profile.name) ||
		    (_view.profile_name != _profile.name && _view.profile_name in _project.profiles.keys))
		{
			_view.warning_message = _("There's already a profile with that name");
			_view.warning_message_visible = true;
			return;
		}
		_view.warning_message_visible = false;
		_view.accept_sensitive = true;
	}
}
