/* projectloader.vala
 *
 * Copyright (C) 2011  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */
using Gee;

namespace I4uc.Core.ProjectLoader
{
	private Project _project;
	private Profile _profile;
	private bool _is_project;
	private bool _is_source_type;
	private string _type_name;
	
	public void load (Project project, string contents) throws GLib.Error
	{
		_project = project;
		MarkupParser parser = { parser_start, parser_end, parser_text, null, null };
		MarkupParseContext context = new MarkupParseContext (parser, 0, null, null);
		context.parse (contents, -1);
	}
	
	private void parser_start (MarkupParseContext context, string name, string[] attr_names, string[] attr_values) throws MarkupError
	{
		switch (name)
		{
			case "project":
				_is_project = true;
				_project.files.clear ();
				for (int i=0; i<attr_names.length; i++)
				{
					switch (attr_names[i])
					{
						case "name":
							_project.name = attr_values[i];
							break;
					}
				}
				break;
			
			case "profile":
				_is_project = false;
				_profile = new Profile ();
				for (int i=0; i<attr_names.length; i++)
				{
					switch (attr_names[i])
					{
						case "name":
							_profile.name = attr_values[i];
							break;
						case "is_public":
							_profile.is_public = attr_values[i].to_bool ();
							break;
					}
				}
				_project.profiles[_profile.name] = _profile;
				break;
			
			case "build_options":
				for (int i=0; i<attr_names.length; i++)
				{
					switch (attr_names[i])
					{
						case "builder":
							_profile.builder = attr_values[i];
							break;
						case "output_type":
							_profile.output_type = attr_values[i];
							break;
						case "device":
							_profile.device = attr_values[i];
							break;
					}
				}
				break;
			
			case "compile_options":
				_is_source_type = true;
				for (int i=0; i<attr_names.length; i++)
				{
					switch (attr_names[i])
					{
						case "source_type":
							_type_name = attr_values[i];
							break;
					}
				}
				_profile.compile_options[_type_name] = new HashMap<string, OptionSettings> ();
				break;
			
			case "link_options":
				_is_source_type = false;
				for (int i=0; i<attr_names.length; i++)
				{
					switch (attr_names[i])
					{
						case "output_type":
							_type_name = attr_values[i];
							break;
					}
				}
				_profile.link_options[_type_name] = new HashMap<string, OptionSettings> ();
				break;
			
			case "option_value":
				var option_settings = new OptionSettings ();
				for (int i=0; i<attr_names.length; i++)
				{
					switch (attr_names[i])
					{
						case "name":
							option_settings.name = attr_values[i];
							break;
						case "active":
							option_settings.active = attr_values[i].to_bool ();
							break;
						case "value":
							option_settings.value = attr_values[i];
							break;
					}
				}
				if (_is_source_type)
					_profile.compile_options[_type_name][option_settings.name] = option_settings;
				else
					_profile.link_options[_type_name][option_settings.name] = option_settings;
				break;
		}
	}
	
	private void parser_end (MarkupParseContext context, string name) throws MarkupError
	{
		switch (name)
		{
			case "profile":
				_is_project = true;
				break;
		}
	}
	
	private void parser_text (MarkupParseContext context, string text, size_t text_len) throws MarkupError
	{
		switch (context.get_element ())
		{
			case "file":
				if (_is_project)
					_project.files.add (text);
				else
					_profile.files.add (text);
				break;
		}
    }
}
