/* settingsloader.vala
 *
 * Copyright (C) 2011  Matias De la Puente
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */

namespace I4uc.Core.SettingsLoader
{
	private Settings _settings;
	private ProgrammerSettings _programmer_settings;
	
	public void load (Settings settings, string filename) throws GLib.Error
	{
		_settings = settings;
		
		var file = File.new_for_path (filename);
		string contents;
		file.load_contents (null, out contents);
		MarkupParser parser = { parser_start, null, parser_text, null, null };
		MarkupParseContext context = new MarkupParseContext (parser, 0, null, null);
		context.parse (contents, -1);
	}
	
	private void parser_start (MarkupParseContext context, string name, string[] attr_names, string[] attr_values) throws MarkupError
	{
		switch (name)
		{
			case "programmer":
				_programmer_settings = new ProgrammerSettings ();
				for (int i=0; i<attr_names.length; i++)
				{
					switch (attr_names[i])
					{
						case "name":
							_programmer_settings.name = attr_values[i];
							break;
					}
				}
				_settings.programmers[_programmer_settings.name] = _programmer_settings;
				break;
			
			case "option_value":
				var option_settings = new OptionSettings ();
				for (int i=0; i<attr_names.length; i++)
				{
					switch (attr_names[i])
					{
						case "name":
							option_settings.name = attr_values[i];
							break;
						case "active":
							option_settings.active = attr_values[i].to_bool ();
							break;
						case "value":
							option_settings.value = attr_values[i];
							break;
					}
				}
				_programmer_settings.options[option_settings.name] = option_settings;
				break;
		}
	}
	
	private void parser_text (MarkupParseContext context, string text, size_t text_len) throws MarkupError
	{
		switch (context.get_element ())
		{
			// MainWindow settings
			case "width":
				_settings.width = text.to_int ();
				break;
			case "height":
				_settings.height = text.to_int ();
				break;
			case "maximized":
				_settings.maximized = text.to_bool ();
				break;
			case "side_panel_visible":
				_settings.side_panel_visible = text.to_bool ();
				break;
			case "bottom_panel_visible":
				_settings.bottom_panel_visible = text.to_bool ();
				break;
			
			// Documents settings
			case "font":
				_settings.font = text;
				break;
			case "tab_width":
				_settings.tab_width = text.to_int ();
				break;
			case "auto_indent":
				_settings.auto_indent = text.to_bool ();
				break;
			case "highlight_current_line":
				_settings.highlight_current_line = text.to_bool ();
				break;
			case "insert_spaces_instead_of_tabs":
				_settings.insert_spaces_instead_of_tabs = text.to_bool ();
				break;
			case "show_line_numbers":
				_settings.show_line_numbers = text.to_bool ();
				break;
			case "highlight_matching_brackets":
				_settings.highlight_matching_brackets = text.to_bool ();
				break;
			case "wrap_mode":
				_settings.wrap_mode = text.to_bool ();
				break;
			
			// Programmers settings
			case "current_programmer":
				_settings.programmer = text;
				break;
		}
    }
}
